@@ -21,7 +21,6 @@ from novaclient import client as nova_client
 from novaclient import exceptions as nova_exception
 from novaclient import utils
 from oslo_config import cfg
-from oslo_log import log
 import six
 
 from manila.common import client_auth
@@ -31,6 +30,7 @@ from manila import exception
 from manila.i18n import _
 
 NOVA_GROUP = 'nova'
+AUTH_OBJ = None
 
 nova_deprecated_opts = [
     cfg.StrOpt('nova_admin_username',
@@ -82,52 +82,61 @@ nova_opts = [
                deprecated_group="DEFAULT",
                deprecated_name="nova_api_microversion",
                help='Version of Nova API to be used.'),
-    cfg.StrOpt('ca_certificates_file',
-               deprecated_group="DEFAULT",
-               deprecated_name="nova_ca_certificates_file",
-               help='Location of CA certificates file to use for nova client '
-                    'requests.'),
-    cfg.BoolOpt('api_insecure',
-                default=False,
-                deprecated_group="DEFAULT",
-                deprecated_name="nova_api_insecure",
-                help='Allow to perform insecure SSL requests to nova.'),
+    cfg.StrOpt('endpoint_type',
+               default='publicURL',
+               help='Endpoint type to be used with nova client calls.'),
+    cfg.StrOpt('region_name',
+               help='Region name for connecting to nova.'),
     ]
 
+# These fallback options can be removed in/after 9.0.0 (Train)
+deprecated_opts = {
+    'cafile': [
+        cfg.DeprecatedOpt('ca_certificates_file', group="DEFAULT"),
+        cfg.DeprecatedOpt('ca_certificates_file', group=NOVA_GROUP),
+        cfg.DeprecatedOpt('nova_ca_certificates_file', group="DEFAULT"),
+        cfg.DeprecatedOpt('nova_ca_certificates_file', group=NOVA_GROUP),
+    ],
+    'insecure': [
+        cfg.DeprecatedOpt('api_insecure', group="DEFAULT"),
+        cfg.DeprecatedOpt('api_insecure', group=NOVA_GROUP),
+        cfg.DeprecatedOpt('nova_api_insecure', group="DEFAULT"),
+        cfg.DeprecatedOpt('nova_api_insecure', group=NOVA_GROUP),
+    ],
+}
+
 CONF = cfg.CONF
 CONF.register_opts(nova_deprecated_opts)
 CONF.register_opts(core_opts)
 CONF.register_opts(nova_opts, NOVA_GROUP)
-ks_loading.register_session_conf_options(CONF, NOVA_GROUP)
+ks_loading.register_session_conf_options(CONF,
+                                         NOVA_GROUP,
+                                         deprecated_opts=deprecated_opts)
 ks_loading.register_auth_conf_options(CONF, NOVA_GROUP)
 
-LOG = log.getLogger(__name__)
-
 
 def list_opts():
     return client_auth.AuthClientLoader.list_opts(NOVA_GROUP)
 
-auth_obj = None
-
 
 def novaclient(context):
-    global auth_obj
-    if not auth_obj:
+    global AUTH_OBJ
+    if not AUTH_OBJ:
         deprecated_opts_for_v2 = {
             'username': CONF.nova_admin_username,
             'password': CONF.nova_admin_password,
             'tenant_name': CONF.nova_admin_tenant_name,
             'auth_url': CONF.nova_admin_auth_url,
         }
-        auth_obj = client_auth.AuthClientLoader(
+        AUTH_OBJ = client_auth.AuthClientLoader(
             client_class=nova_client.Client,
             exception_module=nova_exception,
             cfg_group=NOVA_GROUP,
             deprecated_opts_for_v2=deprecated_opts_for_v2)
-    return auth_obj.get_client(context,
+    return AUTH_OBJ.get_client(context,
                                version=CONF[NOVA_GROUP].api_microversion,
-                               insecure=CONF[NOVA_GROUP].api_insecure,
-                               cacert=CONF[NOVA_GROUP].ca_certificates_file)
+                               endpoint_type=CONF[NOVA_GROUP].endpoint_type,
+                               region_name=CONF[NOVA_GROUP].region_name)
 
 
 def _untranslate_server_summary_view(server):
@@ -284,10 +293,10 @@ class API(base.Base):
             novaclient(context).servers.update(instance_id, name=name)
         )
 
-    def update_server_volume(self, context, instance_id, attachment_id,
+    def update_server_volume(self, context, instance_id, volume_id,
                              new_volume_id):
         novaclient(context).volumes.update_server_volume(instance_id,
-                                                         attachment_id,
+                                                         volume_id,
                                                          new_volume_id)
 
     def keypair_create(self, context, name):
@@ -303,39 +312,13 @@ class API(base.Base):
         return novaclient(context).keypairs.list()
 
     def image_list(self, context):
-        return novaclient(context).images.list()
+        client = novaclient(context)
+        if hasattr(client, 'images'):
+            # Old novaclient with 'images' API proxy
+            return client.images.list()
+        # New novaclient without 'images' API proxy
+        return client.glance.list()
 
     def add_security_group_to_server(self, context, server, security_group):
         return novaclient(context).servers.add_security_group(server,
                                                               security_group)
-
-    def security_group_create(self, context, name, description=""):
-        return novaclient(context).security_groups.create(name, description)
-
-    def security_group_get(self, context, group_id):
-        return novaclient(context).security_groups.get(group_id)
-
-    def security_group_list(self, context, search_opts=None):
-        return novaclient(context).security_groups.list(search_opts)
-
-    def security_group_rule_create(self, context, parent_group_id,
-                                   ip_protocol=None, from_port=None,
-                                   to_port=None, cidr=None, group_id=None):
-        return novaclient(context).security_group_rules.create(
-            parent_group_id, ip_protocol, from_port, to_port, cidr, group_id)
-
-    def security_group_rule_delete(self, context, rule):
-        return novaclient(context).security_group_rules.delete(rule)
-
-    def fixed_ip_reserve(self, context, fixed_ip):
-        return novaclient(context).fixed_ips.reserve(fixed_ip)
-
-    def fixed_ip_unreserve(self, context, fixed_ip):
-        return novaclient(context).fixed_ips.unreserve(fixed_ip)
-
-    def fixed_ip_get(self, context, fixed_ip):
-        return _to_dict(novaclient(context).fixed_ips.get(fixed_ip))
-
-    def network_get(self, context, network_id):
-        """Return network data by its ID."""
-        return _to_dict(novaclient(context).networks.get(network_id))
