@@ -69,22 +69,11 @@ class FakeNovaClient(object):
         def get(self, net_id):
             return Network(net_id)
 
-    class FixedIPs(object):
-        def get(self, fixed_ip):
-            return dict(address=fixed_ip)
-
-        def reserve(self, fixed_ip):
-            return None
-
-        def unreserve(self, fixed_ip):
-            return None
-
     def __init__(self):
         self.servers = self.Servers()
         self.volumes = self.Volumes()
         self.keypairs = self.servers
         self.networks = self.Networks()
-        self.fixed_ips = self.FixedIPs()
 
 
 @nova.translate_server_exception
@@ -152,8 +141,6 @@ class NovaclientTestCase(test.TestCase):
             },
             'nova': {
                 'api_microversion': 'foo_api_microversion',
-                'api_insecure': True,
-                'ca_certificates_file': 'foo_ca_certificates_file',
                 'endpoint_type': 'foo_endpoint_type',
                 'region_name': 'foo_region_name',
             }
@@ -176,8 +163,6 @@ class NovaclientTestCase(test.TestCase):
         mock_client_loader.return_value.get_client.assert_called_once_with(
             fake_context,
             version=data['nova']['api_microversion'],
-            insecure=data['nova']['api_insecure'],
-            cacert=data['nova']['ca_certificates_file'],
             endpoint_type=data['nova']['endpoint_type'],
             region_name=data['nova']['region_name'],
         )
@@ -188,8 +173,6 @@ class NovaclientTestCase(test.TestCase):
         data = {
             'nova': {
                 'api_microversion': 'foo_api_microversion',
-                'api_insecure': True,
-                'ca_certificates_file': 'foo_ca_certificates_file',
                 'endpoint_type': 'foo_endpoint_type',
                 'region_name': 'foo_region_name',
             }
@@ -201,8 +184,6 @@ class NovaclientTestCase(test.TestCase):
         nova.AUTH_OBJ.get_client.assert_called_once_with(
             fake_context,
             version=data['nova']['api_microversion'],
-            insecure=data['nova']['api_insecure'],
-            cacert=data['nova']['ca_certificates_file'],
             endpoint_type=data['nova']['endpoint_type'],
             region_name=data['nova']['region_name'],
         )
@@ -221,6 +202,38 @@ class NovaApiTestCase(test.TestCase):
         self.mock_object(nova, '_untranslate_server_summary_view',
                          lambda server: server)
 
+    def test_image_list_novaclient_has_no_proxy(self):
+        image_list = ['fake', 'image', 'list']
+
+        class FakeGlanceClient(object):
+            def list(self):
+                return image_list
+
+        self.novaclient.glance = FakeGlanceClient()
+
+        result = self.api.image_list(self.ctx)
+
+        self.assertEqual(image_list, result)
+
+    def test_image_list_novaclient_has_proxy(self):
+        image_list1 = ['fake', 'image', 'list1']
+        image_list2 = ['fake', 'image', 'list2']
+
+        class FakeImagesClient(object):
+            def list(self):
+                return image_list1
+
+        class FakeGlanceClient(object):
+            def list(self):
+                return image_list2
+
+        self.novaclient.images = FakeImagesClient()
+        self.novaclient.glance = FakeGlanceClient()
+
+        result = self.api.image_list(self.ctx)
+
+        self.assertEqual(image_list1, result)
+
     def test_server_create(self):
         result = self.api.server_create(self.ctx, 'server_name', 'fake_image',
                                         'fake_flavor', None, None, None)
@@ -316,15 +329,15 @@ class NovaApiTestCase(test.TestCase):
         self.mock_object(self.novaclient.volumes, 'create_server_volume')
         self.api.instance_volume_attach(self.ctx, 'instance_id',
                                         'vol_id', 'device')
-        self.novaclient.volumes.create_server_volume.\
-            assert_called_once_with('instance_id', 'vol_id', 'device')
+        (self.novaclient.volumes.create_server_volume.
+            assert_called_once_with('instance_id', 'vol_id', 'device'))
 
     def test_instance_volume_detach(self):
         self.mock_object(self.novaclient.volumes, 'delete_server_volume')
         self.api.instance_volume_detach(self.ctx, 'instance_id',
                                         'att_id')
-        self.novaclient.volumes.delete_server_volume.\
-            assert_called_once_with('instance_id', 'att_id')
+        (self.novaclient.volumes.delete_server_volume.
+            assert_called_once_with('instance_id', 'att_id'))
 
     def test_instance_volumes_list(self):
         self.mock_object(
@@ -348,8 +361,8 @@ class NovaApiTestCase(test.TestCase):
         self.mock_object(self.novaclient.volumes, 'update_server_volume')
         self.api.update_server_volume(self.ctx, 'instance_id', 'att_id',
                                       'new_vol_id')
-        self.novaclient.volumes.update_server_volume.\
-            assert_called_once_with('instance_id', 'att_id', 'new_vol_id')
+        (self.novaclient.volumes.update_server_volume.
+            assert_called_once_with('instance_id', 'att_id', 'new_vol_id'))
 
     def test_keypair_create(self):
         self.mock_object(self.novaclient.keypairs, 'create')
@@ -359,41 +372,19 @@ class NovaApiTestCase(test.TestCase):
     def test_keypair_import(self):
         self.mock_object(self.novaclient.keypairs, 'create')
         self.api.keypair_import(self.ctx, 'keypair_name', 'fake_pub_key')
-        self.novaclient.keypairs.create.\
-            assert_called_once_with('keypair_name', 'fake_pub_key')
+        (self.novaclient.keypairs.create.
+            assert_called_once_with('keypair_name', 'fake_pub_key'))
 
     def test_keypair_delete(self):
         self.mock_object(self.novaclient.keypairs, 'delete')
         self.api.keypair_delete(self.ctx, 'fake_keypair_id')
-        self.novaclient.keypairs.delete.\
-            assert_called_once_with('fake_keypair_id')
+        (self.novaclient.keypairs.delete.
+            assert_called_once_with('fake_keypair_id'))
 
     def test_keypair_list(self):
         self.assertEqual([{'id': 'id1'}, {'id': 'id2'}],
                          self.api.keypair_list(self.ctx))
 
-    def test_fixed_ip_get(self):
-        fixed_ip = 'fake_fixed_ip'
-        result = self.api.fixed_ip_get(self.ctx, fixed_ip)
-        self.assertIsInstance(result, dict)
-        self.assertEqual(fixed_ip, result['address'])
-
-    def test_fixed_ip_reserve(self):
-        fixed_ip = 'fake_fixed_ip'
-        result = self.api.fixed_ip_reserve(self.ctx, fixed_ip)
-        self.assertIsNone(result)
-
-    def test_fixed_ip_unreserve(self):
-        fixed_ip = 'fake_fixed_ip'
-        result = self.api.fixed_ip_unreserve(self.ctx, fixed_ip)
-        self.assertIsNone(result)
-
-    def test_network_get(self):
-        net_id = 'fake_net_id'
-        net = self.api.network_get(self.ctx, net_id)
-        self.assertIsInstance(net, dict)
-        self.assertEqual(net_id, net['id'])
-
 
 class ToDictTestCase(test.TestCase):
 
